..
  NOTE: This RST file was generated by `make examples`.
  Do not edit it directly.
  See docs/source/examples/example_doc_generator.py

Fields Example
===============================================================================

An example of using Include to generate Field widgets on demand.

There are three columns in the example, each showing one of the many
ways that the Include component may be used.

.. TIP:: To see this example in action, download it from
 :download:`fields <../../../examples/dynamic/fields.enaml>`
 and run::

   $ enaml-run fields.enaml


Screenshot
-------------------------------------------------------------------------------

.. image:: images/ex_fields.png

Example Enaml Code
-------------------------------------------------------------------------------
.. literalinclude:: ../../../examples/dynamic/fields.enaml
    :language: enaml
